@@ -12,8 +12,17 @@ extern bool traceStackOption;
 extern bool traceSourceOption;
 extern bool traceInstructionOption;
 extern bool transcriptOption;
-extern bool logOption;
+extern bool commandLogOption;
 extern bool statusLineOption;
 extern bool regressionTestOption;
+extern bool nopagingOption;
+
+#define ENCODING_ISO 0
+#define ENCODING_UTF 1
+extern int encodingOption;         /* 0 = ISO, 1 = UTF-8 */
+
+
+/* FUNCTIONS: */
+extern void usage(char *programName);
 
 #endif
